/**
 * Kit of [B]inary [C]ode [D]ecimal routines.
 */
public final class BCDKit {
    private BCDKit() {
    }

    /**
     * Converts a 2-digit integer (0..99) to BCD.
     *
     * @param an integer in the range 0..99
     */
    public static byte toBCD(final int n) {
        return (byte) ((n / 10 * 16) + (n % 10));
    }

    /**
     * Converts a value from BCD to plain integer.
     *
     * @param bcdByte a byte holding a BCD-encoded value (in range 0..99)
     */
    public static byte fromBCD(final int bcdByte) {
        final int b = bcdByte & 0xFF;
        return (byte) ((b / 16 * 10) + (b % 16));
    }
}
