import com.pi4j.io.i2c.I2CDevice;
import java.io.IOException;
import java.util.Date;

/**
 * I2C-connected DS1307 Real-Time Clock chip.
 */
public final class DS1307 extends DS1307Registers {

    private static final int RTC_STRUCT_SIZE = 8;
    private static final byte[] RTC_STRUCT = new byte[RTC_STRUCT_SIZE];
    private final I2CDevice rtc;
    
    /**
     * Constructor.
     *
     * @param rtc an I2CDevice pointing to a DS1307
     */
    public DS1307(final I2CDevice rtc) {
        this.rtc = rtc;
    }
    
    /**
     * Read the clock into our local register copies.
     *
     * @throws IOException
     */
     
    public void readClock() throws IOException {
        rtc.read(0, RTC_STRUCT, 0, RTC_STRUCT_SIZE);
        setRegisters(RTC_STRUCT);
    }
    
    /**
     * Write the given Date out to the RTC registers.
     *
     * @param date
     * @throws IOException
     */
     
    public void writeClock(final Date date) throws IOException {
        set(date);
        final byte[] rawRegisterBytes = asByteArray();
        rtc.write(0, rawRegisterBytes, 0, RTC_STRUCT_SIZE);
    }
}
